# Table of Contents

- [collaboration](<./collaboration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Collaboration](<./Collaboration.md>)
  - [Overview](<./Collaboration/Overview.md>)
  - [Collaboration Features in SAP LeanIX](<./Collaboration/Collaboration-Features-in-SAP-LeanIX.md>)
  - [Surveys](<./Collaboration/Surveys.md>)
  - [To-Dos](<./Collaboration/To-Dos.md>)
  - [Comments](<./Collaboration/Comments.md>)
  - [Subscription to Fact Sheets](<./Collaboration/Subscription-to-Fact-Sheets.md>)
  - [Quality Seals](<./Collaboration/Quality-Seals.md>)
  - [Was this page helpful?](<./Collaboration/Was-this-page-helpful.md>)
